
if (CMAKE_VERSION VERSION_LESS 2.8.3)
    message(FATAL_ERROR "Qt 5 requires at least CMake version 2.8.3")
endif()

get_filename_component(_qt5Declarative_install_prefix "${CMAKE_CURRENT_LIST_DIR}/../../../" ABSOLUTE)

set(Qt5Declarative_VERSION_MAJOR 5)
set(Qt5Declarative_VERSION_MINOR 0)
set(Qt5Declarative_VERSION_PATCH 2)
set(Qt5Declarative_VERSION_STRING 5.0.2)

set(Qt5Declarative_LIBRARIES Qt5::Declarative)

macro(_populate_Declarative_target_properties Configuration LIB_LOCATION IMPLIB_LOCATION)
    set_property(TARGET Qt5::Declarative APPEND PROPERTY IMPORTED_CONFIGURATIONS ${Configuration})

    set_target_properties(Qt5::Declarative PROPERTIES
        "IMPORTED_LINK_INTERFACE_LIBRARIES_${Configuration}" "${_Qt5Declarative_LIB_DEPENDENCIES}"
        "IMPORTED_LOCATION_${Configuration}" "${_qt5Declarative_install_prefix}/lib/${LIB_LOCATION}"
    )
    if(NOT "${IMPLIB_LOCATION}" STREQUAL "")
        set_target_properties(Qt5::Declarative PROPERTIES
            "IMPORTED_IMPLIB_${Configuration}" "${_qt5Declarative_install_prefix}/lib/${IMPLIB_LOCATION}"
        )
    endif()
endmacro()

if (NOT TARGET Qt5::Declarative)

    set(Qt5Declarative_INCLUDE_DIRS "${_qt5Declarative_install_prefix}/include/qt5/QtDeclarative")
    set(Qt5Declarative_PRIVATE_INCLUDE_DIRS
        "${_qt5Declarative_install_prefix}/include/qt5/QtDeclarative/${Qt5Declarative_VERSION_STRING}"
        "${_qt5Declarative_install_prefix}/include/qt5/QtDeclarative/${Qt5Declarative_VERSION_STRING}/QtDeclarative"
    )

    set(Qt5Declarative_DEFINITIONS -DQT_DECLARATIVE_LIB)
    set(Qt5Declarative_COMPILE_DEFINITIONS QT_DECLARATIVE_LIB)

    set(_Qt5Declarative_MODULE_DEPENDENCIES "Widgets;Script;Gui;Core")

    set(_Qt5Declarative_FIND_DEPENDENCIES_REQUIRED)
    if (Qt5Declarative_FIND_REQUIRED)
        set(_Qt5Declarative_FIND_DEPENDENCIES_REQUIRED REQUIRED)
    endif()
    set(_Qt5Declarative_FIND_DEPENDENCIES_QUIET)
    if (Qt5Declarative_FIND_QUIETLY)
        set(_Qt5Declarative_DEPENDENCIES_FIND_QUIET QUIET)
    endif()

    foreach(_module_dep ${_Qt5Declarative_MODULE_DEPENDENCIES})
        if (NOT Qt5${_module_dep}_FOUND)
            find_package(Qt5${_module_dep}
                ${_Qt5Declarative_DEPENDENCIES_FIND_QUIET}
                ${_Qt5Declarative_FIND_DEPENDENCIES_REQUIRED}
                PATHS "${_qt5Declarative_install_prefix}" NO_DEFAULT_PATH
            )
        endif()

        if (NOT Qt5${_module_dep}_FOUND)
            set(Qt5Declarative_FOUND False)
            return()
        endif()

        list(APPEND Qt5Declarative_INCLUDE_DIRS "${Qt5${_module_dep}_INCLUDE_DIRS}")
        list(APPEND Qt5Declarative_PRIVATE_INCLUDE_DIRS "${Qt5${_module_dep}_PRIVATE_INCLUDE_DIRS}")
        list(APPEND Qt5Declarative_DEFINITIONS ${Qt5${_module_dep}_DEFINITIONS})
        list(APPEND Qt5Declarative_COMPILE_DEFINITIONS ${Qt5${_module_dep}_COMPILE_DEFINITIONS})
        list(APPEND Qt5Declarative_EXECUTABLE_COMPILE_FLAGS ${Qt5${_module_dep}_EXECUTABLE_COMPILE_FLAGS})
    endforeach()
    list(REMOVE_DUPLICATES Qt5Declarative_INCLUDE_DIRS)
    list(REMOVE_DUPLICATES Qt5Declarative_PRIVATE_INCLUDE_DIRS)
    list(REMOVE_DUPLICATES Qt5Declarative_DEFINITIONS)
    list(REMOVE_DUPLICATES Qt5Declarative_COMPILE_DEFINITIONS)
    if (Qt5Declarative_EXECUTABLE_COMPILE_FLAGS)
      list(REMOVE_DUPLICATES Qt5Declarative_EXECUTABLE_COMPILE_FLAGS)
    endif()

    set(_Qt5Declarative_LIB_DEPENDENCIES "Qt5::Widgets;Qt5::Script;Qt5::Gui;Qt5::Core")

    add_library(Qt5::Declarative SHARED IMPORTED)

    _populate_Declarative_target_properties(RELEASE "Qt5Declarative.dll" "Qt5Declarative.lib" )

    if (EXISTS "${_qt5Declarative_install_prefix}/lib/Qt5Declaratived.dll" AND EXISTS "${_qt5Declarative_install_prefix}/lib/Qt5Declaratived.lib" )
        _populate_Declarative_target_properties(DEBUG "Qt5Declaratived.dll" "Qt5Declaratived.lib" )
    endif()





endif()
